@@ -36,7 +36,7 @@ class mTodos(object):
 
   __pretty_app_name__ = "mTodos"
   __app_name__ = "mTodos"
-  __version__ = "0.2.0"
+  __version__ = "0.2.1"
   __context__ = "net.khertan.mtodos"
 
   _glade_files = [
@@ -133,7 +133,7 @@ class mTodos(object):
     self._now_label = self._widgetTree.get_widget("now_label")
     self._next_label = self._widgetTree.get_widget("next_label")
     self._future_label = self._widgetTree.get_widget("future_label")
-    self._archive_label = self._widgetTree.get_widget("archive_label")
+#    self._archive_label = self._widgetTree.get_widget("archive_label")
 
     threading.Thread(target=self._idle_setup).start()
 
@@ -292,6 +292,10 @@ class mTodos(object):
 
   def _set_category_available(self,widget,isEntry=False):
     gtk.gdk.threads_enter()
+    if isEntry==False:
+      i = widget.get_active()
+      if i<0:
+        i=0
     model = gtk.ListStore(str)
     widget.set_model(model)
     if isEntry==True:
@@ -299,7 +303,7 @@ class mTodos(object):
     for cat in mtodos_framework.TodosList().get_categories():
       model.append((str(cat),))
     if isEntry==False:
-      widget.set_active(0)
+      widget.set_active(i)
     gtk.gdk.threads_leave()
 
   def _open_todo(self,uid):
@@ -540,7 +544,7 @@ class mTodos(object):
     self._now_label.set_markup('<b>Now</b>\n'+str(len(todos_list.get_now_todos(self._current_category)))+' tasks')
     self._next_label.set_markup('<b>Next</b>\n'+str(len(todos_list.get_next_todos(self._current_category)))+' tasks')
     self._future_label.set_markup('<b>Future</b>\n'+str(len(todos_list.get_future_todos(self._current_category)))+' tasks')
-    self._archive_label.set_markup('<b>Archive</b>\n'+str(len(todos_list.get_all_todos(self._current_category)))+' tasks')
+#    self._archive_label.set_markup('<b>Archive</b>\n'+str(len(todos_list.get_all_todos(self._current_category)))+' tasks')
     todos_list.close()
     gtk.gdk.threads_leave()
 
